Custom print method to format the output of model_fight_outcome cleanly to the console using the cli package.

# S3 method for class 'fight_prediction'
print(x, ...)

Arguments

x

An object of class fight_prediction.

...

Additional arguments passed to print.